@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
-# (c) 2020 Andreas Motl <andreas@terkin.org>
+# (c) 2020-2021 Andreas Motl <andreas@terkin.org>
 # License: GNU Affero General Public License, Version 3
 import logging
-from typing import List
 from dataclasses import dataclass
+from typing import List
+from urllib.parse import urlparse
 
+from fastapi import Depends, FastAPI, HTTPException, Query
+from fastapi.responses import HTMLResponse, PlainTextResponse, Response
 from PIL import Image
-from fastapi import FastAPI, Query, Depends, HTTPException
-from fastapi.responses import Response, HTMLResponse, PlainTextResponse
 from pydantic import BaseSettings
 from starlette.status import HTTP_403_FORBIDDEN
-from httptools.parser.parser import parse_url
 
 from imagecast import __appname__, __version__
 from imagecast.core import process
@@ -44,23 +44,26 @@ class QueryOptions:
 
 @app.get("/")
 def index(options: QueryOptions = Depends(QueryOptions)):
-    appname = f'{__appname__} {__version__}'
-    about = 'Imagecast is like ImageMagick but for Pythonistas. Optionally provides its features via HTTP API.'
+    appname = f"{__appname__} {__version__}"
+    about = "Imagecast is like ImageMagick but for Pythonistas. Optionally provides its features via HTTP API."
 
     if options.uri:
 
         # Protect the service from accessing arbitrary remote URIs.
-        uri_parsed = parse_url(options.uri.encode('utf-8'))
-        remote_host = uri_parsed.host.decode()
-        if '*' not in settings.allowed_hosts and remote_host not in settings.allowed_hosts:
+        uri_parsed = urlparse(options.uri.encode("utf-8"))
+        remote_host = uri_parsed.hostname.decode()
+        if (
+            "*" not in settings.allowed_hosts
+            and remote_host not in settings.allowed_hosts
+        ):
             raise HTTPException(status_code=HTTP_403_FORBIDDEN)
 
         # Mogrify image.
         ie = process(options)
 
         # Determine output format.
-        options.format = options.format or ie.image.format
-        if options.format == 'bytes':
+        options.format = options.format or ie.format
+        if options.format == "bytes":
             buffer = ie.to_bytes()
         else:
             buffer = ie.to_buffer(options.format, options.dpi)
@@ -68,12 +71,13 @@ def index(options: QueryOptions = Depends(QueryOptions)):
         # Determine content type.
         mime_type = Image.MIME.get(options.format.upper())
         if mime_type is None:
-            mime_type = 'application/octet-stream'
+            mime_type = "application/octet-stream"
 
         return Response(buffer, media_type=mime_type)
 
     else:
-        return HTMLResponse(f"""
+        return HTMLResponse(
+            f"""
         <html>
             <head>
                 <title>{appname}</title>
@@ -87,7 +91,8 @@ def index(options: QueryOptions = Depends(QueryOptions)):
                 </ul>
             </body>
         </html>
-        """)
+        """
+        )
 
 
 @app.get("/robots.txt", response_class=PlainTextResponse)
@@ -98,8 +103,9 @@ Disallow: /
     """.strip()
 
 
-def start_service(listen_address):
-    host, port = listen_address.split(':')
+def start_service(listen_address, reload: bool = False):
+    host, port = listen_address.split(":")
     port = int(port)
     from uvicorn.main import run
-    run(app='imagecast.api:app', host=host, port=port, reload=True)
+
+    run(app="imagecast.api:app", host=host, port=port, reload=reload)
